﻿using Microsoft.EntityFrameworkCore;
using PiwigoDirectorySync.Infrastructure;
using PiwigoDirectorySync.Persistence;
using Spectre.Console;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Commands;

internal class PiwigoListCommand : CancellableAsyncCommand<PiwigoListCommand.PiwigoListSettings>
{
    private readonly PersistenceContext _persistenceContext;

    public PiwigoListCommand(PersistenceContext persistenceContext)
    {
        _persistenceContext = persistenceContext;
    }

    protected override async Task<int> ExecuteAsync(CommandContext context, PiwigoListSettings settings, CancellationToken cancellation)
    {
        var piwigoServers = await _persistenceContext.PiwigoServers.ToListAsync(cancellation);

        PrintServers(piwigoServers);

        return 0;
    }

    internal static void PrintServers(List<ServerEntity> piwigoServers)
    {
        var table = new Table();
        table.AddColumn(new TableColumn("Server Id").Centered());
        table.AddColumn("Name");
        table.AddColumn("User");
        table.AddColumn("Url");
        table.AddColumn("Path");

        foreach (var piwigoServer in piwigoServers)
        {
            table.AddRow($"[green]{piwigoServer.Id}[/]", piwigoServer.Name, piwigoServer.Username, piwigoServer.Url, piwigoServer.RootDirectory);
        }

        AnsiConsole.Write(table);
    }

    internal class PiwigoListSettings : CommandSettings
    {
    }
}