﻿using System.Diagnostics;
using PiwigoDirectorySync.Infrastructure;
using PiwigoDirectorySync.Services;
using Serilog;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Commands;

internal class SyncAlbumsCommand : CancellableAsyncCommand<SyncAlbumsCommand.SyncAlbumsSettings>
{
    private readonly IAlbumSynchronizer _albumSynchronizer;
    private readonly ILogger _logger = Log.ForContext<SyncAlbumsCommand>();

    public SyncAlbumsCommand(IAlbumSynchronizer albumSynchronizer)
    {
        _albumSynchronizer = albumSynchronizer;
    }

    protected override async Task<int> ExecuteAsync(CommandContext context, SyncAlbumsSettings settings, CancellationToken cancellationToken)
    {
        _logger.Information("Starting album synchronization for piwigo server {SettingsPiwigoServerId}", settings.PiwigoServerId);

        var stopWatch = Stopwatch.StartNew();

        await _albumSynchronizer.SynchronizeAlbums(settings.PiwigoServerId, settings.ReadOnly, cancellationToken);

        stopWatch.Stop();
        _logger.Information("Synchronized all albums with piwigo server {SettingsPiwigoServerId} in {ElapsedTotalSeconds} seconds", settings.PiwigoServerId,
            stopWatch.Elapsed.TotalSeconds);

        return 0;
    }

    internal class SyncAlbumsSettings : SyncCommandSettings
    {
    }
}