﻿using System.Diagnostics;
using PiwigoDirectorySync.Infrastructure;
using PiwigoDirectorySync.Services;
using Serilog;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Commands;

internal class SyncDownloadCommand : CancellableAsyncCommand<SyncDownloadCommand.SyncDownloadSettings>
{
    private readonly IImageSynchronizer _imageSynchronizer;
    private readonly ILogger _logger = Log.ForContext<SyncDownloadCommand>();

    public SyncDownloadCommand(IImageSynchronizer imageSynchronizer)
    {
        _imageSynchronizer = imageSynchronizer;
    }

    protected override async Task<int> ExecuteAsync(CommandContext context, SyncDownloadSettings settings, CancellationToken cancellationToken)
    {
        _logger.Information("Starting image download for piwigo server {SettingsPiwigoServerId}", settings.PiwigoServerId);
        var stopWatch = Stopwatch.StartNew();

        await _imageSynchronizer.DownloadImagesAsync(settings.PiwigoServerId, cancellationToken);

        stopWatch.Stop();
        _logger.Information("Synchronized all images with piwigo server {SettingsPiwigoServerId} in {ElapsedTotalSeconds} seconds", settings.PiwigoServerId,
            stopWatch.Elapsed.TotalSeconds);

        return 0;
    }

    internal class SyncDownloadSettings : CommonCommandSettings
    {
    }
}