﻿using System.Diagnostics;
using PiwigoDirectorySync.Infrastructure;
using PiwigoDirectorySync.Services;
using Serilog;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Commands;

internal class SyncImagesCommand : CancellableAsyncCommand<SyncImagesCommand.SyncImagesSettings>
{
    private readonly IImageSynchronizer _imageSynchronizer;
    private readonly ILogger _logger = Log.ForContext<SyncImagesCommand>();

    public SyncImagesCommand(IImageSynchronizer imageSynchronizer)
    {
        _imageSynchronizer = imageSynchronizer;
    }

    protected override async Task<int> ExecuteAsync(CommandContext context, SyncImagesSettings settings, CancellationToken cancellationToken)
    {
        _logger.Information("Starting image synchronization of piwigo server {SettingsPiwigoServerId}", settings.PiwigoServerId);
        var stopWatch = Stopwatch.StartNew();

        await _imageSynchronizer.SynchronizeImagesAsync(settings.PiwigoServerId, settings.ReadOnly, cancellationToken);

        stopWatch.Stop();
        _logger.Information("Synchronized all images with piwigo server {SettingsPiwigoServerId} in {ElapsedTotalSeconds} seconds", settings.PiwigoServerId,
            stopWatch.Elapsed.TotalSeconds);

        return 0;
    }

    internal class SyncImagesSettings : SyncCommandSettings
    {
    }
}