﻿using PiwigoDirectorySync.Infrastructure;
using PiwigoDirectorySync.Services;
using Spectre.Console;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Commands;

internal class SyncPendingChangesCommand : CancellableAsyncCommand<SyncPendingChangesCommand.SyncPendingChangesSettings>
{
    private readonly IAlbumSynchronizer _albumSynchronizer;
    private readonly IImageSynchronizer _imageSynchronizer;

    public SyncPendingChangesCommand(IAlbumSynchronizer albumSynchronizer, IImageSynchronizer imageSynchronizer)
    {
        _albumSynchronizer = albumSynchronizer;
        _imageSynchronizer = imageSynchronizer;
    }

    protected override async Task<int> ExecuteAsync(CommandContext context, SyncPendingChangesSettings settings, CancellationToken cancellation)
    {
        var pendingAlbumChanges = await _albumSynchronizer.GetPendingChangesAsync(settings.PiwigoServerId, cancellation);
        var pendingImageChanges = await _imageSynchronizer.GetPendingChangesAsync(settings.PiwigoServerId, cancellation);

        var table = new Table();
        table.AddColumn("Entity");
        table.AddColumn(new TableColumn("Check or adds").Centered());
        table.AddColumn(new TableColumn("updates").Centered());
        table.AddColumn(new TableColumn("deletes").Centered());

        table.AddRow("Albums", $"[orange3]{pendingAlbumChanges.CheckOrAdds}[/]", $"[orange3]{pendingAlbumChanges.Updates}[/]", $"[red]{pendingAlbumChanges.Deletes}[/]");
        table.AddRow("Images", $"[orange3]{pendingImageChanges.CheckOrAdds}[/]", $"[orange3]{pendingImageChanges.Updates}[/]", $"[red]{pendingImageChanges.Deletes}[/]");

        AnsiConsole.Write(table);

        return 0;
    }

    internal class SyncPendingChangesSettings : SyncCommandSettings
    {
    }
}