﻿using Microsoft.EntityFrameworkCore;
using PiwigoDirectorySync.Infrastructure;
using PiwigoDirectorySync.Persistence;
using Serilog;
using Spectre.Console;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Commands;

internal class UpdateDatabaseCommand : CancellableAsyncCommand<UpdateDatabaseCommand.UpdateDatabaseSettings>
{
    private readonly ILogger _logger = Log.ForContext<UpdateDatabaseCommand>();
    private readonly PersistenceContext _persistenceContext;

    public UpdateDatabaseCommand(PersistenceContext persistenceContext)
    {
        _persistenceContext = persistenceContext;
    }

    protected override async Task<int> ExecuteAsync(CommandContext context, UpdateDatabaseSettings settings, CancellationToken cancellation)
    {
        try
        {
            await AnsiConsole.Status()
                .Spinner(Spinner.Known.Star)
                .SpinnerStyle(Style.Parse("green bold"))
                .StartAsync("[orange3]Updating database[/]", async _ => { await _persistenceContext.Database.MigrateAsync(cancellation); });
            AnsiConsole.MarkupLine("[green]done[/]");
            return 0;
        }
        catch (Exception ex)
        {
            _logger.Fatal(ex, "Could not update database due to an error {ExMessage}", ex.Message);
            AnsiConsole.WriteException(ex);
        }

        return -1;
    }

    internal class UpdateDatabaseSettings : CommandSettings
    {
    }
}