using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Infrastructure;

public abstract class CancellableAsyncCommand<TSettings> : AsyncCommand<TSettings> where TSettings : CommandSettings
{
    private readonly ConsoleAppCancellationTokenSource _cancellationTokenSource = new();

    protected abstract Task<int> ExecuteAsync(CommandContext context, TSettings settings, CancellationToken cancellation);

    public sealed override async Task<int> ExecuteAsync(CommandContext context, TSettings settings)
    {
        try
        {
            return await ExecuteAsync(context, settings, _cancellationTokenSource.Token);
        }
        catch (TaskCanceledException)
        {
            return -2;
        }
    }
}