using Microsoft.Extensions.DependencyInjection;
using Spectre.Console.Cli;

namespace PiwigoDirectorySync.Infrastructure;

internal sealed class DependencyInjectionTypeRegistrar : ITypeRegistrar
{
    private readonly IServiceCollection _builder;

    public DependencyInjectionTypeRegistrar(IServiceCollection builder)
    {
        _builder = builder;
    }

    public ITypeResolver Build() => new DependencyTypeResolver(_builder.BuildServiceProvider());

    public void Register(Type service, Type implementation)
    {
        _builder.AddSingleton(service, implementation);
    }

    public void RegisterInstance(Type service, object implementation)
    {
        _builder.AddSingleton(service, implementation);
    }

    public void RegisterLazy(Type service, Func<object> func)
    {
        if (func is null)
        {
            throw new ArgumentNullException(nameof(func));
        }

        _builder.AddSingleton(service, _ => func());
    }
}