using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using Microsoft.EntityFrameworkCore;

namespace PiwigoDirectorySync.Persistence;

[Index(nameof(AlbumId), nameof(FilePath), IsUnique = true)]
[Index(nameof(ServerImageId))]
public class ImageEntity
{
    [Key]
    [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
    public int Id { get; set; }

    public int? ServerImageId { get; set; }

    public required string FilePath { get; set; }

    [NotMapped] public string Name => Path.GetFileNameWithoutExtension(FilePath);

    [NotMapped] public string FileName => Path.GetFileName(FilePath);

    public DateTime LastChange { get; set; }
    public string? Md5Sum { get; set; }

    public required int AlbumId { get; set; }
    public AlbumEntity Album { get; set; } = null!;

    public bool UploadRequired { get; set; }
    public bool DeleteRequired { get; set; }
}